.. :changelog:

Release History
---------------

The latest version might be updated now and then. To keep things simpler, the latest version will override the previous one and be
incremented over unless it is a milestone.

1.3.0 (2015-07-29) [Latest Version]
++++++++++++++++++

* Handled no internet access case
* Fixed a few bugs
* Removed unnecessary package dependency
* Did some refactoring

1.2.5 (2015-07-23)
++++++++++++++++++

* Did some refactoring
* Message comparison is now in lower case
* Removed console stream for logging
* Whitespace tokenization is now employed in word matching

1.2.0 (2015-07-21)
++++++++++++++++++

* Simplified import
* Fixed bug on that prevents termination

1.1.0 (2015-07-21)
++++++++++++++++++

* Made minor changes for packaging and distribution

1.0.0 (2015-07-21)
++++++++++++++++++

* Jarvy is born!